# This package depends on automagic byte compilation
# https://fedoraproject.org/wiki/Changes/No_more_automagic_Python_bytecompilation_phase_2
%global _python_bytecompile_extra 1

Name:           exaile
Version:        4.0.0
Release:        2%{?dist}
Summary:        Simple but powerful Amarok-style music player for GTK users
License:        GPLv2+
URL:            http://www.exaile.org
Source0:        https://github.com/exaile/exaile/archive/%{version}/%{name}-%{version}.tar.gz
BuildArch:      noarch


BuildRequires:  /usr/bin/pathfix.py
BuildRequires:  python2-rpm-macros

# Dependencies:
# see also https://github.com/exaile/exaile/blob/master/DEPS

BuildRequires:  desktop-file-utils
BuildRequires:  gettext
BuildRequires:  help2man
BuildRequires:  libappstream-glib
BuildRequires:  pygobject3-devel >= 3.13.2
BuildRequires:  gobject-introspection

Requires:       python2
Requires:       gtk3 >= 3.10
Requires:       python2-gstreamer1 >= 1.4
Requires:       gstreamer1-plugins-good >= 1.6
Requires:       gstreamer1-plugins-base >= 1.4
Requires:       python2-mutagen >= 1.10
Requires:       python2-dbus
Requires:       pygobject3 >= 3.13.2
Requires:       python2-cairo
Requires:       cairo-gobject
Requires:       python2-gobject

# Device detection:
Recommends:     libudisks2
# CD info:
Recommends:     python2-cddb
# DAAP plugins (daapserver and daapclient):
#Not packaged for Fedora
#Recommends:     spydaap
# Last.FM integration:
Recommends:     python2-pylast
# Lyrics from lyricsmania.com (lyricsmania):
Recommends:     python2-lxml
# Lyrics from lyrics.wikia.com (lyricwiki):
Recommends:     python2-beautifulsoup4
# Musicbrainz covers:
Recommends:     python2-musicbrainzngs
# Podcast plugin:
#Not packaged for Fedora
#Recommends:     python2-feedparser
# Wikipedia info:
Recommends:     webkit2gtk3
# Xlib-based hotkeys:
Recommends:     keybinder3
# Scalable icons:
Recommends:     librsvg2
# Native Notifications:
Recommends:     libnotify
# Recording streams:
Recommends:     streamripper
# Moodbar plugin:
#FTBFS on Fedora 30+, may be dropped soon
#Recommends:     moodbar
# BPM Counter plugin:
#Not packaged for Fedora
#* bpmdetect from gstreamer1-plugins-bad


%description
Exaile is a music player with a simple interface and powerful music
management capabilities. Features include automatic fetching of album art,
lyrics fetching, streaming internet radio, tabbed playlists, smart
playlists with extensive filtering/search capabilities, and much more. 

Exaile is written using Python and GTK+ and is easily extensible via
plugins. There are over 50 plugins distributed with Exaile that include
advanced track tagging, last.fm scrobbling, support for portable media
players, podcasts, internet radio such as icecast and Soma.FM,
ReplayGain, output via a secondary output device (great for DJs!), and
much more.

%prep
%setup -q
# Corresponding to:
# 1. Do not silently bytecompile.
# 2. Preserve timestamps.
find . -type f -name "Makefile" -exec \
    sed -i -e 's|compileall -q|compileall|g' \
    -e 's|install -m|install -pm|g' \
{} + -print

%build
%make_build

%install
%make_install PREFIX=%{_prefix} LIBINSTALLDIR=%{_datadir} PYTHON2_CMD=%{__python2}

# Some files got ambiguous python shebangs, we fix them after everything else is done
pathfix.py -pni "%{__python2}" %{buildroot}%{_datadir}/exaile/

desktop-file-install --delete-original			\
	--dir=%{buildroot}%{_datadir}/applications	\
	%{buildroot}%{_datadir}/applications/%{name}.desktop

%find_lang %{name}

%check
appstream-util validate-relax --nonet %{buildroot}%{_datadir}/appdata/*.appdata.xml
#make test

%files -f %{name}.lang
%doc README.md
%license COPYING
%{_bindir}/exaile
%{_datadir}/appdata/exaile.appdata.xml
%{_datadir}/applications/exaile.desktop
%{_datadir}/bash-completion/completions/exaile
%{_datadir}/fish/vendor_completions.d/exaile.fish
%{_datadir}/pixmaps/exaile.png
%{_datadir}/exaile/
%{_datadir}/dbus-1/services/org.exaile.Exaile.service
%dir %{_sysconfdir}/xdg/exaile/
%config(noreplace) %{_sysconfdir}/xdg/exaile/settings.ini
%{_mandir}/man1/exaile*.1*

%changelog
* Sat Jun 22 2019 Christian Stadelmann <genodeftest@fedoraproject.org> - 4.0.0-2
- Update dependencies, add plugin dependencies as optional

* Thu Jun 20 2019 Leigh Scott <leigh123linux@googlemail.com> - 4.0.0-1
- Update to 4.0.0

* Thu Jan 31 2019 Fedora Release Engineering <releng@fedoraproject.org> - 3.4.5-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 3.4.5-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Fri Feb 09 2018 Igor Gnatenko <ignatenkobrain@fedoraproject.org> - 3.4.5-8
- Escape macros in %%changelog

* Wed Feb 07 2018 Fedora Release Engineering <releng@fedoraproject.org> - 3.4.5-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Tue Feb 06 2018 Iryna Shcherbina <ishcherb@redhat.com> - 3.4.5-6
- Update Python 2 dependency declarations to new packaging standards
  (See https://fedoraproject.org/wiki/FinalizingFedoraSwitchtoPython3)

* Sat Aug 26 2017 William Moreno <williamjmorenor@gmail.com> - 3.4.5-5
- Update requires to python2 binary rename

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 3.4.5-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 3.4.5-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Wed Feb 03 2016 Fedora Release Engineering <releng@fedoraproject.org> - 3.4.5-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Fri Jul 10 2015 Christopher Meng <rpm@cicku.me> - 3.4.5-1
- Update to 3.4.5

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.4.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Fri Jan 09 2015 Christopher Meng <rpm@cicku.me> - 3.4.3-1
- Update to 3.4.3

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.3.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Fri Feb 21 2014 Deji Akingunola <dakingun@gmail.com> - 3.3.2-1
- Update to 3.3.2

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.3.1-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Fri Mar 08 2013 Jon Ciesla <limburgher@gmail.com> - 3.3.1-3
- Drop desktop vendor tag.

* Wed Feb 13 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.3.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Sat Nov 17 2012 Deji Akingunola <dakingun@gmail.com> - 3.3.1-1
- Update to 3.3.1

* Mon Sep 24 2012 Deji Akingunola <dakingun@gmail.com> - 3.3.0-1
- Update to 3.3.0

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.3.2.2-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.3.2.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Mon Sep 12 2011 Deji Akingunola <dakingun@gmail.com> - 0.3.2.2-2
- Place exaile's private modules in %%datadir
- Trim (un-necessary?) requires

* Wed Aug 31 2011 Deji Akingunola <dakingun@gmail.com> - 0.3.2.2-1
- Update to 0.3.2.2
- Drop hal. Apply patch to support udisk from upstream bzr's udisk branch

* Thu Mar 03 2011 Deji Akingunola <dakingun@gmail.com> - 0.3.2.1-1
- Update to 0.3.2.1

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.3.2.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Wed Jul 21 2010 David Malcolm <dmalcolm@redhat.com> - 0.3.2.0-2
- Rebuilt for https://fedoraproject.org/wiki/Features/Python_2.7/MassRebuild

* Mon Jun 28 2010 Deji Akingunola <dakingun@gmail.com> - 0.3.2.0-1
- Update to 0.3.2.0

* Wed Jun 09 2010 Deji Akingunola <dakingun@gmail.com> - 0.3.1.2-1
- Update to 0.3.1.2

* Fri Apr 09 2010 Deji Akingunola <dakingun@gmail.com> - 0.3.1.1-1
- Update to 0.3.1.1

* Sat Mar 20 2010 Deji Akingunola <dakingun@gmail.com> - 0.3.1.0-1
- Update to 0.3.1.0

* Wed Nov 25 2009 Deji Akingunola <dakingun@gmail.com> - 0.3.0.2-1
- Update to 0.3.0.2

* Wed Sep 30 2009 Deji Akingunola <dakingun@gmail.com> - 0.3.0.1-1
- Update to 0.3.0.1

* Fri Aug 28 2009 Deji Akingunola <dakingun@gmail.com> - 0.3.0-1
- Update to 0.3.0

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.2.14-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Tue Feb 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.2.14-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Sun Nov 30 2008 Ignacio Vazquez-Abrams <ivazqueznet+rpm@gmail.com> - 0.2.14-2
- Rebuild for Python 2.6

* Thu Oct 09 2008 Deji Akingunola <dakingun@gmail.com> - 0.2.14-1
- Update to 0.2.14

* Fri Jul 11 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 0.2.13-3
- fix license tag

* Mon Jul 07 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 0.2.13-2
- fix conditional comparison
- add sparc64 to 64bit arch check

* Wed Apr 02 2008 Deji Akingunola <dakingun@gmail.com> - 0.2.13-1
- Update to 0.2.13

* Sun Feb 10 2008 Deji Akingunola <dakingun@gmail.com> - 0.2.11.1-2
- Rebuild for gcc43

* Thu Nov 29 2007 Deji Akingunola <dakingun@gmail.com> - 0.2.11.1-1
- Update to 0.2.11.1 that removes bogus cruft from 0.2.11 source tarball
- Rebuild for firefox-2.0.0.10

* Tue Nov 06 2007 Deji Akingunola <dakingun@gmail.com> - 0.2.11-2
- Rebuild for firefox-2.0.0.9

* Mon Oct 22 2007 Deji Akingunola <dakingun@gmail.com> - 0.2.11-1
- New release

* Tue Sep 11 2007 Deji Akingunola <dakingun@gmail.com> - 0.2.10-3
- Require pygtk2-libglade (BZ #278471)

* Wed Aug 22 2007 Deji Akingunola <dakingun@gmail.com> - 0.2.10-2
- Rebuild

* Fri Aug 03 2007 Deji Akingunola <dakingun@gmail.com> - 0.2.10-2
- License tag update

* Sat Jun 30 2007 Deji Akingunola <dakingun@gmail.com> - 0.2.10-1
- New release

* Fri Mar 30 2007 Deji Akingunola <dakingun@gmail.com> - 0.2.9-1
- New release

* Tue Jan 09 2007 Deji Akingunola <dakingun@gmail.com> - 0.2.8-1
- New release

* Sat Dec 30 2006 Deji Akingunola <dakingun@gmail.com> - 0.2.7-1
- New release

* Wed Dec 27 2006 Deji Akingunola <dakingun@gmail.com> - 0.2.6-3
- Rework the python include patch

* Wed Dec 27 2006 Deji Akingunola <dakingun@gmail.com> - 0.2.6-2
- Rewrite the build patch to be more generic

* Tue Dec 26 2006 Deji Akingunola <dakingun@gmail.com> - 0.2.6-1
- First version for Fedora Extras
